## What's the big picture?

Artificial Intelligence conjures up all sorts of images --- perhaps you think of friendly systems that can talk to you and solve tough problems; or maniac robots that are bent on world domination? There's the promise of driverless cars that are safer than human drivers, and the worry of  medical advice systems that hold people's lives in their virtual hands. The field of Artificial Intelligence is a part of computer science that has a lot of promise and also raises a lot of concerns. It can be used to make decisions in systems as large as an aeroplane or an [autonomous dump truck](http://www.komatsu.com/CompanyInfo/profile/product_supports/), or as small as a mobile phone that accurately predicts text being typed into it. What they have in common is that they try to mimic aspects of human intelligence. And importantly, such systems can be of significant help in people's everyday lives.

AI (also known as intelligent systems) is primarily a branch of computer science but it has borrowed a lot of concepts and ideas from other fields, especially [mathematics](https://en.wikipedia.org/wiki/Mathematics) (particularly logic, combinatorics, statistics, probability and optimisation theory), [biology](https://en.wikipedia.org/wiki/Biology), [psychology](https://en.wikipedia.org/wiki/Psychology), [linguistics](https://en.wikipedia.org/wiki/Linguistics), [neuroscience](https://en.wikipedia.org/wiki/Neuroscience) and [philosophy](https://en.wikipedia.org/wiki/Philosophy).
